<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv_SE">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finns ett liv utanför webbläsaren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licensierad till: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 är fri programvara men utvecklingen tar värdefull tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vänligen &lt;a href=&apos;%1&apos;&gt; donera&lt;/a&gt; för att stödja den fortsatta utvecklingen utav %2</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Översätt %1 till ditt modersmål med %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Drivs av %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Mjukvara med öppen källkod</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon designad av %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Släppt under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Ange dina Licensdetaljer</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-post:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Nyckel:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Vänligen licensiera %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Den fulla versionen tillåter dig att kolla på videoklipp utan avbrott.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Genom att köpa fullversionen kommer du också att stödja mitt hårda arbete jag gör med %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Använd demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Ange Licens</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Köp licens</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Ladda ner</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Av %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Du har %n nytt videoklipp</numerusform><numerusform>Du har %n nya videoklipp</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alla Videor</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Osedda Videor</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Senast Uppdaterade</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Senast Tillagda</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Senast Sedda</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Mest Sedda</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortera enligt</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Markera alla som sedda</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Visa Uppdaterat</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Du har inga prenumerationer. Använd stjärnsymbolen för att prenumerera på kanaler.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alla Videor</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Osedda Videor</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Markera som Sedd</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Avprenumerera</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Det finns inga uppdaterade prenumerationer just nu.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Just nu</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n timme sedan</numerusform><numerusform>%n timmar sedan</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visningar</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte / sekund</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB / sekund</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB / sekund</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 återstår</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 nedladdad i %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Nedladdning klar</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Byt plats ...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Välj hämtningsplats</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Hämtningsplatsen har ändrats.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktuella nedladdningar kommer fortfarande att hamna i den tidigare hämtningsplatsen.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Hämtar till: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Nedladdningar</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Den körbara filen har blivit manipulerad, kanske ett virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 kan inte köras. Testa att ominstallera.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Ominstallera</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Spela / Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Sluta spela efter nuvarande spår</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Nästa spår</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Föregående spår</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Öka volymen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Minska volymen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Sök framåt</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Sök bakåt</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Hitta videor och kanaler genom ett nyckelord</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Sök videor enligt kategori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Prenumerationer</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanalprenumerationer</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Gör det bekvämt för dig</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fönster</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimera</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stoppa uppspelningen och gå tillbaka till Sökvyn</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Fö&amp;regående</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gå tillbaka till föregående spår</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>H&amp;oppa</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Hoppa till nästa video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spela</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Återuppta uppspelning</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Helskärm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Använd helskärm</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Kompakt läge</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Dölj spellistan och verktygsfältet</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Öppna &amp;YouTube-sidan</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå till YouTube-video-sidan och pausa uppspelning</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopiera YouTube-&amp;Länk</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopiera den aktuella YouTube-video-länken till urklipp</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopiera videoströmmens &amp;URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopiera den nuvarande videoströmmens URL till urklipp</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Hitta Videodelar</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Hitta andra videodelar förhoppningsvis i rätt ordning</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Ta bort de markerade videoklippen från spellistan</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytta &amp;upp</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytta upp de markerade videoklippen i spellistan</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytta &amp;nedåt</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytta ner de markerade videoklippen i spellistan</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Rensa Senaste Sökningar</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Rensa sökhistorik. Kan inte ångras.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avsluta</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Hej då</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Webbsida</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på webben</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Gör en &amp;Donation</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Vänligen stöd den fortsatta utvecklingen av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Volym av</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Starta Spela &amp;Manuellt</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Starta Spela Videos Manuellt</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Nedladdningar</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Visa detaljer om videonedladdningar</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Ladda ner</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Ladda ner den aktuella videon</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ta &amp;Skärmbild</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Prenumerera på Kanalen</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Dela nuvarande video med %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-post</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Flyt ovanpå</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stoppa efter denna video</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Rapportera ett problem...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Förfinad sökning...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mer...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Relaterade Videor</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Visa videor relaterade till den nuvarande</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Öppna i &amp;Webbläsare</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Älskar du %1? Betygsätt den!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Köp %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Applikation</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Uppspelning</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Spellista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Dela</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vy</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Tryck på %1 för att öka volymen, %2 för att sänka den</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Välj plats för din volym</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Öppnar %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vill du avsluta %1 med en nedladdning igång?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Om du stänger %1 nu, avbryts nedladdningen.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Stäng och avbryt nedladdning</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Vänta på att nedladdning blir klar</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fel: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausa uppspelning</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Laddar...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Lämna &amp;Helskärm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Återstående tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volym %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ljudet är avstängt</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volymen är på</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Högsta videoupplösning är satt till %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Din integritet är nu säker</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Nedladdningar klara</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Nu kan du klistra in YouTube-länken i ett annat program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan nu klistra in videoströmmens webbadress i ett annat program</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Länken kommer att gälla endast under en begränsad tid.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Hämtar %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>av</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>avsnitt</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Skickad från %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Avbryt prenumeration från %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Prenumerera på %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Prenumeration avbruten från %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Prenumererad på %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>En ny version av %1 Finns tillgänglig!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 är nu tillgänglig. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vill du ladda ner den nu?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Hoppa Över Denna Version</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Påminn mig senare</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Uppdatera</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 av %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Förbereder</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Misslyckades</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Färdig</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppad</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Stoppa nedladdning</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Visa i %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Öppna ursprungsmappen</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Starta om nedladdning</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Visa %1 Till</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Inga videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Inga fler videor</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortera enligt</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Mest sedda</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Betyg</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>När som helst</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Idag</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dagar</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dagar</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Längd</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mellan</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lång</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Kortare än 4 minuter</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mellan 4 och 20 minuter</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Längre än 20 minuter</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Färdig</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Färdig</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Välkommen till &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>för att börja titta på video.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>ett sökord</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Ange</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Senaste sökord</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Senaste kanaler</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Skaffa den kompletta versionen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tillbaka</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Framåt till %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Tillbaka till %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Förfinad sökning</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Menade du: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Byt plats ...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Skärmbild sparad till %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Plats för sparade skärmbilder ändrades.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Mest Populär</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Laddar ner uppdatering...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Laddar ner uppdatering...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan inte få videoström för %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeriet</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australien</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgien</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasilien</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tjeckiska Republiken</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypten</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankrike</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Tyskland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grekland</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hongkong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungern</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indien</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesien</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanien</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marocko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nederländerna</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nya Zeeland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filippinerna</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Ryssland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudiarabien</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sydafrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sydkorea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanien</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Sverige</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisien</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turkiet</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Förenade Arabemiraten</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Storbritannien</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Från Hela Världen</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan inte få videoström för %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>En ny version av %1 Finns tillgänglig!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 är nu tillgänglig. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vill du ladda ner den nu?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Påminn mig senare</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>